@@ -123,14 +123,14 @@ class UsersAndGroup(object):
                     if "groups" not in user:
                         user["groups"] = [g]
                     elif type(user["groups"]) == list:
-                        user["groups"].appand(g)
+                        user["groups"].append(g)
                     else:
                         user["groups"] = [g]
                 elif key in self._ARRAY_FIELDS:
                     if key not in user:
                         user[key] = u[key]
                     elif type(user[key]) != list:
-                        user[key].appand(u[key])
+                        user[key].append(u[key])
                     else:
                         user[key] = [u[key]]
                 else:
